@@ -42,6 +42,7 @@ def excecuteElement(config,records,ps_delete_query):
             sql_insert_query = "INSERT INTO mobile (id, model, price)  VALUES (%s,%s,%s)"
     """
     res = 0
+    connection = None
     try:
         connection = psycopg2.connect(host=config['host'],port=config['port'],database=config['database'],user=config['user'],password=config['password'])
         cursor = connection.cursor()
@@ -53,10 +54,11 @@ def excecuteElement(config,records,ps_delete_query):
         res = -1
         writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error excecuteElement : " + str(error)+'\n'+('**'*45)+'\n\n',root_directory_name="",dir_name = '_LOG_Postgres')
     finally:
-        # closing database connection.
         if connection:
-            cursor.close()
-            connection.close()
+            # closing database connection.
+            if connection:
+                cursor.close()
+                connection.close()
     return res
 
 def selectElement(config,where,sql_select_query,one=False):
@@ -73,6 +75,7 @@ def selectElement(config,where,sql_select_query,one=False):
     """
     
     record = None
+    connection=None
     try:
         connection = psycopg2.connect(host=config['host'],port=config['port'],database=config['database'],user=config['user'],password=config['password'])
         cursor = connection.cursor()
@@ -86,10 +89,11 @@ def selectElement(config,where,sql_select_query,one=False):
         writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error selectElement : "+ str(error)+('**'*45)+'\n\n' ,root_directory_name="",dir_name = '_LOG_Postgres')
 
     finally:
-        # closing database connection.
         if connection:
-            cursor.close()
-            connection.close()
+            # closing database connection.
+            if connection:
+                cursor.close()
+                connection.close()
     return record
 
 def excecuteSQL(config,sql_query):
@@ -103,6 +107,7 @@ def excecuteSQL(config,sql_query):
         Boolean: resul of query (True or False)
     """
     res = False
+    connection = None
     try:
         connection = psycopg2.connect(host=config['host'],port=config['port'],database=config['database'],user=config['user'],password=config['password'])
         cursor = connection.cursor()
@@ -113,8 +118,9 @@ def excecuteSQL(config,sql_query):
         print("Error while connecting to PostgreSQL :", error)
         writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error excecuteSQL : "+str(error)+('**'*45)+'\n\n',root_directory_name="",dir_name = '_LOG_Postgres')
     finally:
-        # closing database connection.
         if connection:
-            cursor.close()
-            connection.close()
+            # closing database connection.
+            if connection:
+                cursor.close()
+                connection.close()
     return res
\ No newline at end of file
